@@ -1,15 +1,16 @@
 package Statocles::Theme;
 # ABSTRACT: Templates, headers, footers, and navigation
-$Statocles::Theme::VERSION = '0.020';
+$Statocles::Theme::VERSION = '0.021';
 use Statocles::Class;
+use Statocles::Store;
 use File::Share qw( dist_dir );
 use Scalar::Util qw( blessed );
 
 
-has path => (
+has store => (
     is => 'ro',
-    isa => Path,
-    coerce => Path->coercion,
+    isa => InstanceOf['Statocles::Store'],
+    coerce => Statocles::Store->coercion,
 );
 
 
@@ -24,9 +25,9 @@ has templates => (
 around BUILDARGS => sub {
     my ( $orig, $self, @args ) = @_;
     my $args = $self->$orig( @args );
-    if ( $args->{path} && $args->{path} =~ /^::/ ) {
-        my $name = substr $args->{path}, 2;
-        $args->{path} = Path::Tiny->new( dist_dir( 'Statocles' ) )->child( 'theme', $name );
+    if ( $args->{store} && !ref $args->{store} && $args->{store} =~ /^::/ ) {
+        my $name = substr $args->{store}, 2;
+        $args->{store} = Path::Tiny->new( dist_dir( 'Statocles' ) )->child( 'theme', $name );
     }
     return $args;
 };
@@ -35,13 +36,14 @@ around BUILDARGS => sub {
 sub read {
     my ( $self ) = @_;
     my %tmpl;
-    my $iter = $self->path->iterator({ recurse => 1, follow_symlinks => 1 });
+    my $iter = $self->store->path->iterator({ recurse => 1, follow_symlinks => 1 });
     while ( my $path = $iter->() ) {
         if ( $path =~ /[.]ep$/ ) {
             my $name = $path->basename( '.ep' ); # remove extension
             my $group = $path->parent->basename;
             $tmpl{ $group }{ $name } = Statocles::Template->new(
                 path => $path,
+                include_dirs => [ $self->store->path ],
             );
         }
     }
@@ -59,7 +61,7 @@ sub coercion {
     my ( $class ) = @_;
     return sub {
         return $_[0] if blessed $_[0] and $_[0]->isa( $class );
-        return $class->new( path => $_[0] );
+        return $class->new( store => $_[0] );
     };
 }
 
@@ -75,7 +77,7 @@ Statocles::Theme - Templates, headers, footers, and navigation
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -84,7 +86,7 @@ version 0.020
     /theme/blog/index.html.ep
     /theme/blog/post.html.ep
 
-    my $theme      = Statocles::Theme->new( path => '/theme' );
+    my $theme      = Statocles::Theme->new( store => '/theme' );
     my $layout     = $theme->template( site => 'layout.html' );
     my $blog_index = $theme->template( blog => 'index.html' );
     my $blog_post  = $theme->template( blog => 'post.html' );
@@ -95,14 +97,14 @@ A Theme contains all the L<templates|Statocles::Template> that
 L<applications|Statocles::App> need. This class handles finding and parsing
 files into L<template objects|Statocles::Template>.
 
-When the L</path> is read, the templates inside are organized based on
+When the L</store> is read, the templates inside are organized based on
 their name and their parent directory.
 
 =head1 ATTRIBUTES
 
-=head2 path
+=head2 store
 
-The source directory for this theme.
+The source L<store|Statocles::Store> for this theme.
 
 If the path begins with ::, will pull one of the Statocles default
 themes from the Statocles share directory.
